@@ -49,8 +49,6 @@
 
 package com.openexchange.realtime.json.actions;
 
-import java.util.Arrays;
-import java.util.Collection;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
@@ -81,11 +79,6 @@ public class RealtimeActions implements AJAXActionServiceFactory {
         SEND = new SendAction(services, stateManager, protocolHandler);
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return Arrays.asList("enrol", "poll", "query", "send");
-    }
-
     @Override
     public AJAXActionService createActionService(String action) throws OXException {
         if ("enrol".equals(action)) {
